# Taurus firmware upload script
# Nanometrics Inc. (c) 2004
#
RELEASE_DIR=.
ip_base=1.0.0.2

echo "taurus_install.sh [-options]"
echo "options:"
echo "         -nodigitizer : does not update the digitizer section of the Taurus"
echo "         -nopwm       : does not update the power Manager"
echo "         -noapps      : does not update the Taurus applications"
echo
echo "Killing running applications..."
kill_taurus
# pkill in case the server was in the process of going up...
pkill -9 taurus

# Parse command line
notdp=""
nopwm=""
noapps=""
while [ "x$1" != "x" ] ; do
	if [ "$1" = "-nodigitizer" ] ; then
		notdp=Y
		nopwm=Y
	fi
	if [ "$1" = "-nopwm" ] ; then
		nopwm=Y
	fi
	if [ "$1" = "-noapps" ] ; then
		noapps=Y
	fi
	shift
done

echo
if [ "$noapps" = "Y" ] ; then
	echo "Root filesystem update skipped."
else
	echo "Updating Root filesystem..."
	./rootfs-update*.sh
fi

echo 
if [ "$notdp" = "Y" ] ; then
	echo "TDP skipped."
else
	wget -q http://1.0.0.2/firmware/
	arm_partition=`./get_arm_partition`

	echo -n "Uploading to ARM partition " 
	echo -n $arm_partition
	echo "..."

	rm -rf ./index.html

	echo -n "  `find $RELEASE_DIR -name "TDP_ARM_*.nbf"`: "
	curl --config curl_post_firmware -F firmware=@`find $RELEASE_DIR -name "TDP_ARM_*.nbf"` $ip_base/firmware/arm/$arm_partition
	echo
	echo -n "  `find $RELEASE_DIR -name "TDP_FPGA_*.nbf"`: "
	curl --config curl_post_firmware -F firmware=@`find $RELEASE_DIR -name "TDP_FPGA_*.nbf"` $ip_base/firmware/fpga/$arm_partition
	echo
	echo -n "  `find $RELEASE_DIR -name "TaurusDsp*.nbf"`: "
	curl --config curl_post_firmware -F firmware=@`find $RELEASE_DIR -name "TaurusDsp*.nbf"` $ip_base/firmware/dsp/$arm_partition
	echo
	echo -n "  `find $RELEASE_DIR -name "Coeff*.nbf"`: "
	curl --config curl_post_firmware -F firmware=@`find $RELEASE_DIR -name "Coeff*.nbf"` $ip_base/firmware/coefficients/$arm_partition
	echo
fi

if [ "$nopwm" = "Y" ] ; then
	echo "Power Manager skipped."
else
	wget -q http://1.0.0.2/pwm/
	pwm_partition=`./get_pwm_partition` 

	echo -n "Uploading to power manager partition " 
	echo -n $pwm_partition
	echo "..."

	rm -rf ./index.html

	echo -n "  `find $RELEASE_DIR -iname "PowerMgr*$pwm_partition.nbf"`: "
	curl --config curl_post_firmware -F firmware=@`find $RELEASE_DIR -iname "PowerMgr*$pwm_partition.nbf"` $ip_base/pwm/$pwm_partition
	echo
fi

echo
echo "Uploading kernel image..."
/etc/init.d/kernel upload `find $RELEASE_DIR -name "TCP_uImage*"`
echo 

if [ "$noapps" = "Y" ] ; then
	echo "Applications skipped."
else
	echo "Installing taurus applications..."
	echo -n "  `find $RELEASE_DIR -name "taurus*.tgz"`: "
	tar zxf `find $RELEASE_DIR -name "taurus*.tgz"` -C /
	echo "Done"
	echo -n "  `find $RELEASE_DIR -name "TCP-apps-ui*.tgz"`: "
	tar zxf `find $RELEASE_DIR -name "TCP-apps-ui*.tgz"` -C /
	echo "Done"

	echo
	echo "Store files may not be compatible... remember to erase the store database if required..."
fi

echo
echo "Install complete."
echo
